#
# spec file for package StyLua
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _bin_name stylua
Name:           StyLua
Version:        0.18.2
Release:        1.1
Summary:        Opinionated Lua code formatter
License:        (Apache-2.0 OR MIT) AND Unicode-DFS-2016 AND (Apache-2.0 OR BSL-1.0) AND (Apache-2.0 OR MIT) AND (MIT OR Unlicense) AND Apache-2.0 AND MIT AND MPL-2.0 AND MPL-2.0
URL:            https://github.com/JohnnyMorganz/StyLua
Source0:        https://github.com/JohnnyMorganz/StyLua/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
Source2:        cargo_config
BuildRequires:  cargo-packaging
BuildRequires:  rust+cargo
BuildRequires:  zstd

%description
StyLua is an opinonated code formatter for Lua 5.1, 5.2, 5.3, 5.4 and Luau
built using full-moon. StyLua is inspired by the likes of prettier, it
parses your Lua codebase, and prints it back out from scratch, enforcing a
consistent code style.

%prep
%setup -q -a1
mkdir -p .cargo
cp %{SOURCE2} .cargo/config.toml

%build
%{cargo_build} --all-features

%install
%{cargo_install} --all-features

# %%check
# %%{cargo_test} --locked --features lua52
# %%{cargo_test} --locked --features lua53
# %%{cargo_test} --locked --features lua54
# %%{cargo_test} --locked --features luau

%files
%{_bindir}/%{_bin_name}
%license LICENSE.md
%doc README.md

%changelog
* Mon Oct  9 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 0.18.2:
  * Fixed LuaJIT suffixes LL/ULL causing a panic when running in --verify mode
  * Fixed incorrect formatting of conditionals when collapse_simple_statement is enabled and the block begins with an empty line
  * Fixed formatting of dot function call chains with comment between dot and names
* Sat Aug 26 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 0.18.1:
  * Fixed parentheses around a single Luau type pack in a generic being removed causing syntax errors.
* Sun Aug 13 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Replace obsoleted `disabled` option with `manual`
* Sun Jun 18 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 0.18.0:
  * Multiline ignores (-- stylua: ignore start / -- stylua: ignore end) will now work within table fields
  * Added option "Input" to call_parentheses setting, where call parentheses are retained based on their presence in the original input code.
  * Improved heuristics around Luau type excess parentheses removal, so unnecessary parentheses around types are removed in more locations
  * Function calls are now formatted onto multiple lines if the opening brace { of a multiline table forces one of the lines over width
  * Fixed missing option --sort-requires to enable sort requires on the command line
  * Fixed parentheses removed around Luau optional type (B?) causing syntax errors when present in an intersection A & (B?)
  * Fixed comments lost when parentheses removed around Luau types
  * Fixed race condition where if a file is passed more than once as an argument to format, then it could potentially be wiped completely
    (for example, if an ancestor directory is passed and recursively searched, as well as the file itself)
* Fri Jun  9 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 0.17.1
  * Bumped internal parser dependency which should fix parsing problems for comments with Chinese characters, and multiline string escapes
  * Fixed comments in punctuated lists for return statements or assignments being incorrectly formatted leading to syntax errors
  * Fixed line endings not being correctly formatted in multiline string literals and comments
* Tue Mar 21 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Disable tests. Failing for editorconfig.
* Tue Mar 21 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Remove editorconfig requirement.
- Fix tests.
* Tue Mar 21 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Fix tests.
- Add editorconfig as build requirement.
* Sat Mar 18 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 0.17.0:
  * Sort requires
  * Add default editorconfig feature
  * extension: Pass cwd as workspace folder for version check
  * Add Dockerfile
* Fri Feb 17 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 0.16.1:
  * General
  - Fixed mistransformation of a function argument in a multilined function call when the argument
    contains a comment, causing a syntax error. We now attempt to hang the expression (#648)
  * Luau
  - Fixed verify AST flagging a false positive for parentheses removed around a Luau type (#643)
* Tue Feb 14 2023 William Brown <william.brown@suse.com>
- Automatic update of vendored dependencies
* Sat Jan 28 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 0.16.0:
  * Fixed an anonymous function assignment local x = function() being unnecessarily indented if the function body contains a comment (#627)
  * Fixed malformed formatting when there is a newline between a return token and the expressions (#605)
  * Fixed malformed formatting of multi-assignment or multi-returns where there is a comment within the expressions list (#637)
  * Update internal parser:
  - (lua52) Support Lua 5.2 fractional hexidecimal / hexidecimal with exponents (#621)
  - (lua52) Support LuaJIT number suffixes LL/ULL/i (#621)
  - (lua52) Support \z escape sequences in strings (#613)
  - (luau) Support Luau string interpolation (#607)
  * Several optimisations applied to formatting functions to reduce time taken. Files which previously did not terminate (6MB+) now finish in reasonable time. (#591)
  * Assignments of the form local name = function will no longer hang at the equals token, and instead force parameters multiline, to reduce unnecessary indentation. (#595)
  * Unnecessary parentheses around Luau types will now be removed (#611)
  * Collapse a body containing only a goto statement when collapse_simple_statement is set (#618)
* Fri Dec 16 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Disable --all-features in test since `cargo-insta` is
  not installed or available in openSUSE.
* Fri Dec 16 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 0.15.3:
  * Fixed necessary parentheses removed in (-X) ^ Y causing change in semantics
  * Take into account function token size when formatting an anonymous function function() end (particularly relevant when collapsing simple statements)
  * Support hanging inside of Luau type arrays { T } to fix formatting issues when comments are present
* Thu Nov 24 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Remove strip option for debuginfo creation.
* Mon Nov 21 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Rename source tarball to StyLua-0.15.2.tar.gz.
- Update _service file.
* Sun Nov 20 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Change url macro to full URL in sources.
- Profile "release" strips debug symbols in cargo_config.
* Sun Nov 20 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Initial spec for StyLua version 0.15.2
